@@ -159,15 +159,13 @@ static void       accounts_dialog_destroy_cb                (GtkWidget
 static void
 accounts_dialog_setup (EmpathyAccountsDialog *dialog)
 {
-	GtkTreeView      *view;
-	GtkListStore     *store;
-	GtkTreeSelection *selection;
-	GtkTreeIter       iter;
-	GList            *accounts, *l;
+	GtkTreeView  *view;
+	GtkListStore *store;
+	GtkTreeIter   iter;
+	GList        *accounts, *l;
 
 	view = GTK_TREE_VIEW (dialog->treeview);
 	store = GTK_LIST_STORE (gtk_tree_view_get_model (view));
-	selection = gtk_tree_view_get_selection (view);
 
 	accounts = mc_accounts_list ();
 
@@ -215,12 +213,9 @@ accounts_dialog_update_connect_button (EmpathyAccountsDialog *dialog)
 
 	account = accounts_dialog_model_get_selected (dialog);
 	
-	if (!account) {
-		gtk_widget_set_sensitive (dialog->button_connect, FALSE);
-		return;
-	}
+	gtk_widget_set_sensitive (dialog->button_connect, account != NULL);
 
-	if (mc_account_is_enabled (account)) {
+	if (account && mc_account_is_enabled (account)) {
 		label = _("Disable");
 		stock_id = GTK_STOCK_DISCONNECT;
 	} else {
@@ -296,8 +291,7 @@ accounts_dialog_update_account (EmpathyAccountsDialog *dialog,
 		}
 		else {
 			dialog->settings_widget = 
-				empathy_account_widget_generic_new (account,
-								   dialog->label_name);
+				empathy_account_widget_generic_new (account);
 		}
 		
 		gtk_widget_grab_focus (dialog->settings_widget);
@@ -310,17 +304,20 @@ accounts_dialog_update_account (EmpathyAccountsDialog *dialog,
 
 	if (account) {
 		McProfile *profile;
+		gchar     *text;
 
 		profile = mc_account_get_profile (account);
 		gtk_image_set_from_icon_name (GTK_IMAGE (dialog->image_type),
 					      mc_profile_get_icon_name (profile),
 					      GTK_ICON_SIZE_DIALOG);
-		
+		/* FIXME: Uncomment once we depend on GTK+ 2.12
+		gtk_widget_set_tooltip_text (dialog->image_type,
+					     mc_profile_get_display_name (profile));
+		*/
 
-		gtk_label_set_text (GTK_LABEL (dialog->label_type),
-				    mc_profile_get_display_name (profile));
-		gtk_label_set_text (GTK_LABEL (dialog->label_name), 
-				    mc_account_get_display_name (account));
+		text = g_strdup_printf ("<big><b>%s</b></big>", mc_account_get_display_name (account));
+		gtk_label_set_markup (GTK_LABEL (dialog->label_name), text);
+		g_free (text);
 	}
 }
 
@@ -553,6 +550,9 @@ accounts_dialog_model_selection_changed (GtkTreeSelection     *selection,
 	if (account) {
 		g_object_unref (account);
 	}
+
+	/* insure new account frame is hidden when a row is selected*/
+	gtk_widget_hide (dialog->frame_new_account);
 }
 
 static void
@@ -981,7 +981,6 @@ empathy_accounts_dialog_show (GtkWindow *parent)
 				       "button_create", &dialog->button_create,
 				       "button_back", &dialog->button_back,
 				       "image_type", &dialog->image_type,
-				       "label_type", &dialog->label_type,
 				       "label_name", &dialog->label_name,
 				       "button_remove", &dialog->button_remove,
 				       "button_connect", &dialog->button_connect,
